import os
import requests

from .fs import *
# from .fs import cwd
# from .fs import write
# 数据转化
from .to import *
from .desco import *
# from .desco import try_error
# from .desco import calc


# 操作系统指令
# from ..cmd_exe import run


def test():
    print("test            :", 15160)



import shutil, os, pathlib, json


def write(my_path, xxx):
    if isinstance(xxx, dict) or isinstance(xxx, list):
        print("write.字典和数组")
        with open(my_path, 'w+', encoding="utf-8") as f:
            json_str = json.dumps(xxx, ensure_ascii=False, indent=4)
            f.write(json_str)
            print("write.存储完成", my_path)
            return json_str



    elif isinstance(xxx, str):
        print("write.字符")
        with open(my_path, 'w+', encoding="utf-8") as f:
            f.write(xxx)
            print("write.存储完成", my_path)
            return xxx
    else:
        print("write.其它类型")
        return xxx


if __name__ == '__main__':
    res1 = write(r"./dist1111.txt", "222")
    print("res1            :", res1)




import json

def JSON(xxx):
    # 定义一个 JSON 字符串
    json_string = '{"name": "John Doe", "age": 35, "email": "john.doe@example.com"}'

    # 将 JSON 字符串转换为 Python 字典
    my_dict = json.loads(xxx)
    print(   type (my_dict)  )
    
    return my_dict


if __name__ == '__main__':
    xxx = '{"name": "John Doe", "age": 35, "email": "john.doe@example.com"}'
    print("111                 :" ,   JSON(xxx)   )
    pass


import json
import shutil, os, pathlib
from astmain.fs.read import read

from types import SimpleNamespace
from collections import namedtuple
fff222 = dict(read=read)
fff222=SimpleNamespace(**fff222)

if __name__ == '__main__':
    res1 = fff222.read(r"E:\AAA\xxx\ast_chrome\a08_驱动测试_cookie_打包_发布\astmain_py222\astmain\fs\aaa.txt")
    print("res1            :", res1)

    # res2 = fff222(r"E:\AAA\xxx\ast_chrome\a08_驱动测试_cookie_打包_发布\astmain_py222\astmain\fs\maker_config.json").read("obj")
    # print("res2            :", type(res2), res2)



import datetime

from write_add import write_add


# level 默认就好   "error"
# info  必填参数
# path  默认参数   r"C:\log_all.txt"


def log_all(level="error", info="默认内容1", path=r"C:\log_all.txt"):
    """ EXPLAIN : 日志追加记录函数
        PARAMS  :
        level     默认就好   "error"
        info      必填参数
        path      默认参数   r"C:\log_all.txt"

        RETURN  : null
        EXAMPLE :  log_all(info="我的错误", path=r"C:\log_all.txt")
    """

    content = level + "|||" + datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S") + "|||" + info
    write_add(path, content)


if __name__ == '__main__':
    log_all(info="我的错误", path=r"C:\log_all.txt")
